==> blip_ds-0.0.29.tar.gz: lib/src/controllers/ds_video_player.controller.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/material.dart';

import 'package:chewie/chewie.dart';
import 'package:get/get.dart';
import 'package:video_player/video_player.dart';

import 'package:blip_ds/src/services/ds_dialog.service.dart';
import 'package:blip_ds/src/services/ds_file.service.dart';
import 'package:blip_ds/src/themes/colors/ds_colors.theme.dart';
import 'package:blip_ds/src/widgets/buttons/ds_primary_button.widget.dart';
import 'package:blip_ds/src/widgets/buttons/ds_secondary_button.widget.dart';

class DSVideoPlayerController extends GetxController {
  /// Video controller. responsible for managing the state of the video widget, and all
  /// the management of video controls.
  DSVideoPlayerController({
    required this.url,
  });

  // External URL containing the video to be played
  final String url;

  VideoPlayerController? _videoPlayerController;
  ChewieController? chewieController;
  int? bufferDelay;

  @override
  bool isClosed = false;

  RxBool appBarVisible = true.obs;
  RxBool isLoading = true.obs;

  @override
  void onInit() async {
    await initializePlayer();

    super.onInit();
  }

  @override
  void onClose() {
    _videoPlayerController?.dispose();
    chewieController?.dispose();
    _videoPlayerController?.removeListener(_showAppBar);
    isClosed = true;
    super.onClose();
  }

  Future<void> initializePlayer() async {
    try {
      final fileName = url.substring(url.lastIndexOf('/')).substring(1);
      final result = await DSFileService.download(url, fileName);
      if (result?.isNotEmpty ?? false) {
        _videoPlayerController = VideoPlayerController.file(File(result!));

        final completer = Completer<void>();

        await Future<void>(() async {
          _videoPlayerController!
              .initialize()
              .then((_) => completer.complete())
              .catchError((e) {
            _screenError(fileName);
          });

          return completer.future;
        });

        if (!completer.isCompleted) {
          _screenError(fileName);
        } else {
          if (!isClosed) _createChewieController();
        }

        _videoPlayerController?.addListener(_showAppBar);

        isLoading.value = false;
      }
    } on Exception {
      isLoading.value = false;
      Get.back();
    }
  }

  void _screenError(final fileName) {
    Get.back();
    Get.delete<DSVideoPlayerController>();
    final dialog = _dialogErrorFile(fileName);
    dialog.showError();
  }

  DSDialogService _dialogErrorFile(final String fileName) {
    return DSDialogService(
      title: 'Erro ao reproduzir o vídeo',
      text:
          'Encontramos um erro ao reproduzir o vídeo. Você deseja tentar abrir o vídeo externamente?',
      primaryButton: DSPrimaryButton(
        onPressed: () {
          Get.back();
          DSFileService.open(fileName, url);
        },
        label: 'Sim',
      ),
      secondaryButton: DSSecondaryButton(
        onPressed: (() => Navigator.of(Get.context!).pop()),
        label: 'Não',
      ),
      context: Get.context!,
    );
  }

  void _createChewieController() {
    chewieController = ChewieController(
      videoPlayerController: _videoPlayerController!,
      autoPlay: true,
      looping: true,
      allowPlaybackSpeedChanging: true,
      allowMuting: false,
      allowFullScreen: false,
      playbackSpeeds: const [0.5, 1.0, 1.5, 2.0],
      fullScreenByDefault: false,
      progressIndicatorDelay:
          bufferDelay != null ? Duration(milliseconds: bufferDelay!) : null,
      materialProgressColors: ChewieProgressColors(
        playedColor: DSColors.neutralDarkCity,
        handleColor: DSColors.neutralLightSnow,
        backgroundColor: DSColors.neutralDarkCity,
        bufferedColor: DSColors.neutralMediumSilver,
      ),
      autoInitialize: true,
    );
  }

  Future<void> _showAppBar() async {
    appBarVisible.value = !(chewieController!.isPlaying);
  }
}

==> blip_ds-0.0.44.tar.gz: lib/src/controllers/ds_video_player.controller.dart <==
import 'dart:async';
import 'dart:io';

import 'package:chewie/chewie.dart';
import 'package:get/get.dart';
import 'package:path_provider/path_provider.dart';
import 'package:video_player/video_player.dart';

import '../themes/colors/ds_colors.theme.dart';
import '../widgets/chat/video/ds_video_error.dialog.dart';

class DSVideoPlayerController extends GetxController {
  /// Video controller. responsible for managing the state of the video widget, and all
  /// the management of video controls.
  DSVideoPlayerController({
    required this.url,
    required this.uniqueId,
  });

  // External URL containing the video to be played
  final String url;

  final String uniqueId;

  VideoPlayerController? _videoPlayerController;
  ChewieController? chewieController;
  int? bufferDelay;

  @override
  bool isClosed = false;

  RxBool appBarVisible = true.obs;
  RxBool isLoading = true.obs;

  @override
  void onInit() async {
    await _initializePlayer();
    super.onInit();
  }

  @override
  void onClose() {
    _videoPlayerController?.dispose();
    chewieController?.dispose();

    isClosed = true;
    super.onClose();
  }

  Future<void> _initializePlayer() async {
    final fileName = url.substring(url.lastIndexOf('/')).substring(1);

    try {
      final temporaryPath = (await getTemporaryDirectory()).path;
      final outputFile = File("$temporaryPath/VIDEO-$uniqueId.mp4");

      _videoPlayerController =
          VideoPlayerController.file(File(outputFile.path));

      await _videoPlayerController!.initialize();
      _createChewieController();

      isLoading.value = false;
    } catch (e) {
      isLoading.value = false;
      _showErrorDialog(fileName);
    }
  }

  Future<void> _showErrorDialog(final fileName) async {
    Get.back();
    Get.delete<DSVideoPlayerController>();
    await DSVideoErrorDialog.show(fileName, url);
  }

  void _createChewieController() {
    chewieController = ChewieController(
      showOptions: false,
      videoPlayerController: _videoPlayerController!,
      autoPlay: true,
      looping: true,
      allowPlaybackSpeedChanging: false,
      allowMuting: false,
      allowFullScreen: false,
      playbackSpeeds: const [0.5, 1.0, 1.5, 2.0],
      fullScreenByDefault: false,
      progressIndicatorDelay:
          bufferDelay != null ? Duration(milliseconds: bufferDelay!) : null,
      materialProgressColors: ChewieProgressColors(
        playedColor: DSColors.neutralDarkCity,
        handleColor: DSColors.neutralLightSnow,
        backgroundColor: DSColors.neutralDarkCity,
        bufferedColor: DSColors.neutralMediumSilver,
      ),
      autoInitialize: true,
    );
  }
}
